@font-face {
  font-family: 'Material Icons';
  font-style: normal;
  font-weight: 400;
  src: url("flUhRq6tzZclQEJ-Vdg-IuiaDsNZ.ttf") format('truetype');
}
@font-face {
  font-family: 'Roboto';
  font-style: normal;
  font-weight: 100;
  src: url("KFOkCnqEu92Fr1MmgWxP.ttf") format('truetype');
}
@font-face {
  font-family: 'Roboto';
  font-style: normal;
  font-weight: 300;
  src: url("KFOlCnqEu92Fr1MmSU5vAw.ttf") format('truetype');
}
@font-face {
  font-family: 'Roboto';
  font-style: normal;
  font-weight: 400;
  src: url("KFOmCnqEu92Fr1Me5Q.ttf") format('truetype');
}
@font-face {
  font-family: 'Roboto';
  font-style: normal;
  font-weight: 500;
  src: url("KFOlCnqEu92Fr1MmEU9vAw.ttf") format('truetype');
}
@font-face {
  font-family: 'Roboto';
  font-style: normal;
  font-weight: 700;
  src: url("KFOlCnqEu92Fr1MmWUlvAw.ttf") format('truetype');
}
@font-face {
  font-family: 'Roboto';
  font-style: normal;
  font-weight: 900;
  src: url("KFOlCnqEu92Fr1MmYUtvAw.ttf") format('truetype');
}

.material-icons {
  font-family: 'Material Icons';
  font-weight: normal;
  font-style: normal;
  font-size: 24px;
  line-height: 1;
  letter-spacing: normal;
  text-transform: none;
  display: inline-block;
  white-space: nowrap;
  word-wrap: normal;
  direction: ltr;
}
